import subprocess

import pytest

from univention.config_registry import ConfigRegistry
from univention.config_registry.frontend import ucr_update
from univention.testing import utils

import samltest


@pytest.fixture(scope='session')
def ucr() -> ConfigRegistry:
    ucr = ConfigRegistry()
    ucr.load()

    return ucr


@pytest.fixture(scope='session')
def kerberos_ucr(ucr) -> ConfigRegistry:
    original_vars = {'kerberos/defaults/rdns': None, 'saml/idp/authsource': None}
    for key in original_vars.keys():
        original_vars[key] = ucr.get(key, None)

    ucr_update(ucr, {'kerberos/defaults/rdns': 'false', 'saml/idp/authsource': 'univention-negotiate'})

    yield ucr

    ucr_update(ucr, original_vars)


@pytest.fixture()
def kerberos_ticket(kerberos_ucr) -> None:
    subprocess.call(['kdestroy'])

    # get kerberos ticket
    if saml_session().keycloak:
        subprocess.check_call(['kinit', '--password-file=/var/lib/ucs-test/pwdfile', 'Administrator'])
    else:
        subprocess.check_call(['kinit', '--password-file=/etc/machine.secret', kerberos_ucr['hostname'] + '$'])

    yield

    subprocess.call(['kdestroy'])


@pytest.fixture()
def saml_session():
    account = utils.UCSTestDomainAdminCredentials()
    return samltest.SamlTest(account.username, account.bindpw)
